Functions
=========

This page contains an index of the functions present in the package and a description of them.


Voxelization
------------

.. automodule:: dendromatics.voxel.voxel
   :members:
   :undoc-members:
   :show-inheritance:


Height-normalization
--------------------

.. automodule:: dendromatics.ground
   :members:
   :undoc-members:
   :show-inheritance:


Stem extraction
---------------

.. automodule:: dendromatics.stripe
   :members:
   :undoc-members:
   :show-inheritance:


Tree individualization
----------------------

.. automodule:: dendromatics.individualize
   :members:
   :undoc-members:
   :show-inheritance:


Computing sections
------------------

.. automodule:: dendromatics.sections
   :members:
   :undoc-members:
   :show-inheritance:


Drawing LAS files
-----------------

.. automodule:: dendromatics.draw
   :members:
   :undoc-members:
   :show-inheritance:
